@@ -43,10 +43,10 @@
 #'@param highlight Syntax highlighting style. Supported styles include
 #'  "default", "tango", "pygments", "kate", "monochrome", "espresso", "zenburn",
 #'  "haddock", and "textmate". Pass \code{NULL} to prevent syntax highlighting.
-#'@param mathjax Include mathjax. The "default" option uses an https URL from
-#'  the official MathJax CDN. The "local" option uses a local version of MathJax
-#'  (which is copied into the output directory). You can pass an alternate URL
-#'  or pass \code{NULL} to exclude MathJax entirely.
+#'@param mathjax Include mathjax. The "default" option uses an https URL from a
+#'  MathJax CDN. The "local" option uses a local version of MathJax (which is
+#'  copied into the output directory). You can pass an alternate URL or pass
+#'  \code{NULL} to exclude MathJax entirely.
 #'@param section_divs Wrap sections in <div> tags (or <section> tags in HTML5),
 #'  and attach identifiers to the enclosing <div> (or <section>) rather than the
 #'  header itself.
@@ -506,7 +506,7 @@ html_highlighters <- function() {
 }
 
 default_mathjax <- function() {
-  paste("https://cdn.mathjax.org/mathjax/latest/",
+  paste("https://mathjax.rstudio.com/latest/",
         mathjax_config(), sep="")
 }
 
