@@ -47,7 +47,7 @@ shiny_prerendered_app <- function(input_rmd, encoding, render_args) {
   # remove server code before serving
   server_contexts <-  c("server-start", "data", "server")
   html_lines <- shiny_prerendered_remove_contexts(html_lines, server_contexts)
-  html <- HTML(paste(html_lines, collapase = "\n"))
+  html <- HTML(paste(html_lines, collapse = "\n"))
   html <- htmltools::attachDependencies(html, deps)
 
   # create shiny app
